#
# spec file for package racket
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2012, 2013 Togan Muftuoglu toganm@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           racket
Version:        7.3
Release:        bp153.1.109
Summary:        Scheme implementation with teaching tools
License:        LGPL-2.1-or-later AND GPL-3.0-or-later
Group:          Development/Languages/Scheme
URL:            http://racket-lang.org
Source0:        http://download.racket-lang.org/installers/%{version}/%{name}-%{version}-src.tgz
Source2:        racket-completion.bash
Source3:        racket-rpmlintrc
Patch0:         racket-doc.patch
Patch1:         dont-strip.patch
BuildRequires:  ImageMagick
BuildRequires:  ca-certificates
BuildRequires:  chrpath
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ghostscript-fonts-std
BuildRequires:  libexpat1
BuildRequires:  libjpeg-devel
BuildRequires:  librsvg-devel
BuildRequires:  libtool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libedit)
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pixman-1) >= 0.22.0
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(zlib)
# The rpmbuild does not detect those! 
Requires:       libcairo2
Requires:       libedit0
Requires:       libglib-2_0-0
Requires:       libgtk-3-0
Requires:       libpango-1_0-0
Requires:       libsqlite3-0
Provides:       %{name}-drracket = %{version}-%{release}
Provides:       %{name}-games = %{version}-%{release}
Provides:       %{name}-webserver = %{version}-%{release}
Recommends:     racket-doc = %{version}-%{release}

%define add_optflags(a:f:t:p:w:W:d:g:O:A:C:D:E:H:i:M:n:P:U:u:l:s:X:B:I:L:b:V:m:x:c:S:E:o:v:) \
%global optflags %{optflags} %{**}

# maggia has this
# Disable the debug package since otherwise a build would create the following
# error message:
#  *** ERROR: same build ID in nonidentical files!
#          /usr/bin/mzscheme
#     and  /usr/bin/mred
# this should be set from the obs
#%%define debug_package %%nil

%description
Racket (formerly called PLT Scheme) is a multi-paradigm programming language
in the Lisp/Scheme family, that also serves as a platform for language
creation, design, and implementation.

The programming language is known for its powerful macro system which enables
the creation of embedded and domain-specific languages, language constructs
such as classes or modules, and separate dialects of Racket enable different
semantics.

%package        doc
Summary:        Documentation HTML files for Racket
Group:          Development/Languages/Scheme
Provides:       %{name}:%{_docdir}/%{name}/docindex.sqlite
BuildArch:      noarch

%description    doc
A local installation of the Racket documentation system.

%package devel
Summary:        Development header files for Racket
Group:          Development/Languages/Scheme
Requires:       %{name} = %{version}-%{release}
Requires:       glibc-devel
Requires:       libffi-devel

%description devel
This package contains the symlinks, headers and object files needed to
compile and link programs which use Racket.


%prep
%setup -q
%patch0 -p0
%patch1 -p1

cp -p %{SOURCE2} src/

%build
cd src/

%add_optflags -D_DEFAULT_SOURCE -D_XOPEN_SOURCE=500 -fno-gcse
%configure  --prefix="%{_datadir}" --docdir="%{_defaultdocdir}/%{name}" --enable-shared \
    --disable-static --disable-strip --enable-places --enable-lt="%{_bindir}/libtool" \
    --enable-pthread

make %{?_smp_mflags} VERBOSE=1

%install
cd src/

# use the following if setting extra plt_setup options
# export LD_LIBRARY_PATH=%%{buildroot}%%{_libdir}
# export PLT_SETUP_OPTIONS="-j 1 "

install -d %{buildroot}/%{_datadir}/doc/%{name}/

%make_install

# we do not need *.la and *.a files

find %{buildroot}%{_libdir} -name "*.la" -delete
find %{buildroot}%{_libdir} -name "*.a" -delete
find %{buildroot}%{_datadir} -name ".LOCKpkgs.rktd" -delete

# make system clear
for bin in mred mzscheme racket
do
    test -e $bin || continue
    chrpath --delete %{buildroot}%{_bindir}/$bin || :
done
for bin in gracket starter
do
    test -e $bin || continue
    chrpath --delete %{buildroot}%{_libdir}/$bin || :
done
for bin in c-printf crypt esd magick sndfile tcl xmmsctrl xosd
do
    bin=%{buildroot}%{_datadir}/%{name}/pkgs/racket-doc/ffi/examples/use-${bin}.rkt
    test -e $bin || continue
    sed -ri '1s@(/usr/bin/)env +@\1@p' $bin
    chmod 755 $bin
done
chmod 755 %{buildroot}%{_datadir}/%{name}/pkgs/htdp-lib/2htdp/uchat/xrun

for html in syntax/module-helpers rackunit/api reference/collects
do
    html=%{_docdir}/%{name}/${html}.html
    test -e $html || continue
    sed -ri 's@%{buildroot}@@g' $html
done

# Bash completion
install -Dm 644 %{SOURCE2} %{buildroot}%{_datadir}/bash_completion/completions/%{name}
install -Dm 644 %{_builddir}/%{name}-%{version}/share/pkgs/drracket/drracket/drracket.png %{buildroot}%{_datadir}/pixmaps/drracket.png

# rewrite path in .desktop files

%suse_update_desktop_file -c drracket "DrRacket" "DrRacket is an interactive, integrated, graphical programming environment for the Racket programming languages" "%{_bindir}/drracket" "drracket" Development IDE
%suse_update_desktop_file -c slideshow "Slideshow" "Slideshow is a Racket-based tool for writing slide presentations as programs" "%{_bindir}/slideshow" "drracket" Development Documentation

# Due package split we do this explicit to support older rpm version as well
install -m 0644 ../README %{buildroot}%{_docdir}/%{name}/README

%fdupes %{buildroot}%{_prefix}

%post
/sbin/ldconfig
%desktop_database_post

%postun
/sbin/ldconfig
%desktop_database_postun

%files
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/README
%{_bindir}/drracket
%{_bindir}/gracket
%{_bindir}/gracket-text
%{_bindir}/mred
%{_bindir}/mred-text
%{_bindir}/mzc
%{_bindir}/mzpp
%{_bindir}/mzscheme
%{_bindir}/mztext
%{_bindir}/pdf-slatex
%{_bindir}/plt-games
%{_bindir}/plt-help
%{_bindir}/plt-r5rs
%{_bindir}/plt-r6rs
%{_bindir}/plt-web-server
%{_bindir}/racket
%{_bindir}/raco
%{_bindir}/scribble
%{_bindir}/setup-plt
%{_bindir}/slatex
%{_bindir}/slideshow
%{_bindir}/swindle
%{_libdir}/libracket3m-%{version}.so
%{_libdir}/%{name}/mzdyn3m.o
%{_datadir}/%{name}/*
%{_libdir}/%{name}/starter
%{_libdir}/%{name}/gracket
%{_libdir}/%{name}/starter-sh
%{_libdir}/%{name}/*.rktd
%{_mandir}/man1/mz*
%{_mandir}/man1/racket*
%{_mandir}/man1/raco*
%{_mandir}/man1/setup-plt*
%{_mandir}/man1/drracket*
%{_mandir}/man1/gracket*
%{_mandir}/man1/mred*
%{_mandir}/man1/plt-help*
%dir %{_libdir}/%{name}
%dir %{_datadir}/%{name}
%dir %{_datadir}/bash_completion
%dir %{_datadir}/bash_completion/completions
%dir %{_sysconfdir}/%{name}
%{_datadir}/bash_completion/completions/%{name}
%config %{_sysconfdir}/%{name}/config.rktd
%{_datadir}/applications/drracket.desktop
%{_datadir}/applications/slideshow.desktop
%{_datadir}/pixmaps/drracket.png
%exclude %{_datadir}/%{name}/pkgs/mzscheme-lib/mzscheme/examples/*

%files doc
%doc %{_docdir}/%{name}/*
%exclude %{_docdir}/%{name}/README

%files devel
%{_includedir}/%{name}/*
%{_libdir}/%{name}/buildinfo
%{_libdir}/libracket3m.so
%dir %{_includedir}/%{name}
%{_datadir}/%{name}/pkgs/mzscheme-lib/mzscheme/examples/*

%changelog
* Tue Mar 24 2020 Adrian Schröter <adrian@suse.de>
- adapt _constraints, sse3 never existed, but this is not anymore
  ignored in OBS
* Tue Jul 16 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to 7.3:
  * There is a new set of teaching languages for the upcoming
    German-language textbook "Schreibe Dein Programm!"
  * Racket's IO system has been refactored to improve performance
    and simplify internal design.
  * Racket's JSON reader is dramatically faster.
  * The `plot` library includes color map support for renderers.
  * The Racket web library has improved support for 307 redirects.
  * The Racket web server provides better response messages by default
    for common status codes.
  * The `pict` library includes a `shear` function.
- remove patches:
  * extflvector-length-inlined.patch: included in release
- clean up spec file
  * %%foo -> %%{foo}
  * remove %%defattr
  * multiple other smaller clean ups
- Remove extflvector-length-inlined.patch
* Wed Apr  3 2019 Andreas Schwab <schwab@suse.de>
- dont-strip.patch: don't strip libraries
* Mon Apr  1 2019 Dr. Werner Fink <werner@suse.de>
- Add patch extflvector-length-inlined.patch from upstream commit
  80f84f21 to get extflvector-length work even on i586
- Add patch racket-doc.patch to be able to split package into
  main and doc pacakges
* Fri Mar 29 2019 Dr. Werner Fink <werner@suse.de>
- Spec file clean up
- Try to get it work on some ix86 CPU versions
* Wed Mar 27 2019 Dr. Werner Fink <werner@suse.de>
- Require some missed libraries and certificates for build
  as well as for installation even if rmplint cries
- Update to racket 7.2
  * The contract system supports collapsible contracts, which avoid
    repeated wrappers in certain pathological situations. Thanks to Daniel
    Feltey.
  * Quickscript, a scripting tool for DrRacket, has become part of the
    standard distribution. Thanks to Laurent Orseau.
  * The web server's built-in configuration for serving static files
    recognizes the ".mjs" extension for JavaScript modules.
  * The `data/enumerate` library supports an additional form of
    subtraction via `but-not/e`, following Yorgey and Foner's ICFP'18
    paper. Thanks to Max New.
  * The `letrec.rkt` example model in Redex has been changed to more
    closely match Racket, which led to some bug fixes in Racket's
    implementation of `letrec` and `set!`.
  * The racklog library has seen a number of improvements, including fixes
    to logic variable binding, logic variables containing predicates being
    applicable, and the introduction of an `%%andmap` higher-order predicate.
* Thu Nov 29 2018 Tomasz Olszewski <olszewst@gmail.com>
- Downgrade to Racket 7.1
  * 7.1.0.1 was only a snapshot release and is already gone from
    Racket mirrors
* Sat Oct 13 2018 sean@suspend.net
- Update to Racket 7.1.0.1
  * Syntax (#') now supports new template subforms: ~@ and ~?
  * Interactive overlays can be added to plots produced by plot-snip
  * Added contrcat-equivalent?, a way to compare contracts
  * Lazy Racket supports functions with keyword arguments
* Mon Jun 25 2018 schwab@suse.de
- gc-aarch64.patch: remove obsolete patch, this GC implementation is no
  longer used.
* Wed Dec 27 2017 kgronlund@suse.com
- Update to Racket 6.11
  * Typed Racket supports refinement types and dependent function types.
  * DrRacket’s Program Contour is significantly more efficient
  * The web-server/formlets library produces formlets that are serializable
  * The db library supports the Cassandra database
- Ensure more system resources when building package
* Sun Sep 24 2017 olszewst@gmail.com
- Racket version bumped to 6.10.1.
- Spec changes
  * Drop --collectsdir in %%configure in favour of --prefix (%%configure
    would fail otherwise)
  * Drop 0-size file guard. This used to delete lock files (LOCKpkgs.rktd)
    lack of which would result in errors in many contexts, including
    basic usage of both DrRacket and raco (package manager)
  * Drop %%_datadir/%%name/collects from %%dir, because parent folder is already
    included in another %%dir entry. This fixes a warning about collects folder
    being listed twice.
  * Added reference to starter-sh.
  * Drop DrRacket's -singleInstance option from %%suse_update_desktop_file. This
    option caused error messages coming from %%suse_update_desktop_file itself.
* Sat Mar 11 2017 sfalken@opensuse.org
- Edited %%files to explicity package %%{_docdir}/%%{name} to clear
  unpackaged files builderror in openSUSE:Factory
* Fri Jul 29 2016 jengelh@inai.de
- Guard 0-size deletion by -type f, as other types can have
  size 0 too. Run spec-beautifier to bring (almost) all macro uses
  into same style.
* Mon Jul 25 2016 kgronlund@suse.com
- Update to Racket 6.6
* Sun Aug 11 2013 schwab@suse.de
- gc-aarch64.patch: add support for aarch64
  Sat May  3 01:37:00 UTC 2014 - MihailJP
- Spec changes
  * Collection 'config' should be included in main package
* Sat Aug 10 2013 toganm@opensuse.org
- Update to Racket 5.3.6
  * This is a bug fix release.  It eliminates errors from v5.3.5
    that people have found over the summer.
- Spec changes
  * remove libpng16.patch and libpng16-adjustment.patch
  * rather then use of mirrors for source downloads use the main
    site as mirrors are not uptodate
* Tue Jun 18 2013 toganm@opensuse.org
- Update to Racket v5.3.5
  * This is a special-purpose release to match the arrival of "Realm of
    Racket" in bookstores.  Racket v.5.3.5 adds a single `realm'
    collection to the v5.3.4 release.  The new collection contains the
    source code that readers of Realm may wish to use for experiments.
- Add racket to the requires of webserver subpackage
* Fri May 17 2013 toganm@opensuse.org
- Added backported patches libpn16.patch and libpng16-adjustment.patch
  correcting libpn16
- Fix randomly generated mode 666 documentation files
* Tue May 14 2013 toganm@opensuse.org
- Update to 5.3.4 release for details see changelog.txt and News
  * Extflonums (80-bit floating-point numbers) are supported on some
    x86/x86_64 platforms -- including Windows, and including platforms
    where Racket is compiled to use SSE instructions for flonum
    arithmetic.  Thanks to Michael Filonenko.
  * Tally Maze: a new game based an enumeration of 2d mazes.
  * The Optimization Coach, a DrRacket plugin, has been moved from the
    Racket distribution to the Racket package repository.  Install it
    with: raco pkg install optimization-coach
  * Redex: `define-union-language' now merges productions when
    languages define the same nonterminals.  Thanks to William Bowman.
  * The `srfi/19' library is now compatible with the date structure
    type exported by `racket/base'.
- Packaging changes
  * 0001-Fix-install-path-for-doc-and-collects.patch based on debian
    patch but correct doc install directory as well, this patch also
    enable the removal of 0001-pkg-collects-path.patch
  * For Factory use libpng12 as racket is not compatible with
    libpng16
  * Include libtools to BuildRequires, not to depend on bundled software
    in the source package
  * Include full URL for the source package
* Fri Mar 15 2013 cfarrell@suse.com
- license update: LGPL-2.1+ and GPL-3.0+
  testsuite contains GPL-3.0+ licensed code
* Sat Feb 16 2013 toganm@opensuse.org
- Update to 5.3.3 release for details see changelog.txt and News
  * This is a bug-fix release to address a flaw in DrRacket v5.3.2
    concerning interactions between the contour window and the syntax
    coloring.
* Fri Feb  1 2013 toganm@opensuse.org
- Update to 5.3.2 release for details see changelog.txt and News
  * Changed case to use equal? instead of eqv?
  * Changed log-message to support a name argument
  * Changed the synchronization result of a log receiver to include an
    event name
  * Added exn:fail:filesystem:errno and exn:fail:network:errno
  * Added phantom byte strings
  * Added 'word mode to system-type
  * Added arguments to impersonate-prompt-tag and chaperone-prompt-tag
    to support interposition on non-composable continuation results
  * Add #fx() and #fl() reader forms for flvectors and fxvectors
  * racket/unsafe/ops: added unsafe-cons-list
  * racket/gui: added get-current-mouse-state, and added
    display-changed to frame%%
  * racket/serialize: fxvectors and flvectors are serializable
  * racket/net: added uri-path-segment-unreserved-encode
  * racket/url: added current-url-encode-mode
  * racket/date: fixed 'iso-8601 date formatting
  * scribble/tag: added
  * scribble/base: added make-section-tag, taglet?
    r5rs, r6rs: fixed case and cond to disallow internal definitions
    in clauses
  * ffi/com: added com-get-property*
  * file/untar: added
  * file/untgz: added
  * file/unzip: added
  * compiler/zo-structs: generalize flonum? field to type
    field in localref, let-one, and fun
  * compiler/zo-structs: added a constantness field to module-variable
* Thu Nov  8 2012 toganm@opensuse.org
- Update to 5.3.1 release for details see changelog and News
  * Changed make-log-receiver to accept a logger name as an event
    filter
  * Addded define-logger
  * Changed -W, -L, PLTSTDERR, and PLTSYSLOG to support log filters
    of the form "<level> <name>=<level> ..."
  * Changed log-error, etc., to support format mode
  * Added racket/format, which is re-exported by racket
  * Added #:break and #:final clauses to for forms
  * Added exn:break:hang-up and exn:break:terminate, added extra
    argument to break-thread and place-break, and redirect SIGTERM
    and SIGHUP as breaks
  * Add #:fill option to for/vector, for*/vector, for/flvector,
    for*/flvector, for/fxvector, and for*/fxvector
  * Added PLTCOMPILEDROOTS and --compiled/-R command-line flag
  * Added reroot-path
  * Changed a thread's initial prompt to use the default handler
    (instead of accepting and ignoring abort arguments)
  * ffi/unsafe: added cpointer-gcable?
  * racket/class: added dynamic-get-field and dynamic-set-field!
  * racket/set: added set-first and set-rest, sets are streams
  * racket/require-transformer: an import's module path can be syntax
  * scribble/base: add items/c
  * scribble/decode: add spliceof
  * syntax/for-body: added
- drop racket-glibc-2.16.patch
* Thu Oct 11 2012 toganm@opensuse.org
- enabled documentation
* Wed Aug  8 2012 toganm@opensuse.org
- Update to official 5.3 release
* Wed Aug  1 2012 toganm@opensuse.org
- split packaging
* Thu Jul 26 2012 toganm@opensuse.org
- Use the upcoming version 5.3.0.16 from nightly builds
  * add racket.desktop
  * disable documentation as it breaks the build
- TODO
  * fix the rpmlint warnings for srfi
* Tue May  1 2012 toganm@opensuse.org
- Initial packaging for racket-lang
